==> wes-button-toggle-0.1.1.tgz: package/README.md <==
# `@salesforce-ux/wes-button-toggle`
[![npm (custom registry)](https://img.shields.io/npm/v/@salesforce-ux/wes-button-toggle/latest?color=green&label=npm%20package)](https://www.npmjs.com/package/@salesforce-ux/wes-button-toggle)

## About

The Button Toggle provides feedback of its pressed and unpressed state.

## Getting Started

Let's start by installing wes-button-toggle as a dependency of your project with [npm](https://www.npmjs.com/package/@salesforce-ux/wes-button-toggle).

```
npm i @salesforce-ux/wes-button-toggle
```
## Distributable
After installation, all the distributables for the `wes-button-toggle` are found under `/node_modules/@salesforce-ux/wes-button-toggle/dist/` folder.

|File Name             |Description     |
|--------------------- |--------------- |
|`button-toggle.css`          | The CSS file specific to `wes-button-toggle` only. It doesnot include the styles for it's parent `sds-button-toggle`. `wes-button-toggle` extends from `sds-button-toggle`|
|`button-toggle.compiled.css` | The Compiled CSS file for `wes-button-toggle`. This file includes styles for both `wes-button-toggle` and its parent `sds-button-toggle`. This file is useful for **LWC** applications.([see below](#for-lightning-web-componentlwc-application) &rarr;)|
|`button-toggle.js`           | The bundled JS file for `wes-button-toggle` component. This file is useful for **Non LWC** applications.([see below](#for-non-lwc-application) &rarr;)|

## `wes-button-toggle` Integration

For the sake of understanding, we have categorized the development environment into LWC and Non LWC application.    
This Guide covers the integration approach for these two types of application.

### For `Lightning Web Component(LWC)` Application

> #### Dependency Inclusion

[`wes-styling-hooks`](https://www.npmjs.com/package/@salesforce-ux/wes-styling-hooks) is a styling dependency for `wes-button-toggle`. Hence, this needs to be embedded into the root of the web app in order to make the `wes-button-toggle` render properly.

```html
<html>
  <head>
    <link rel="stylesheet" href="/node_modules/@salesforce-ux/wes-styling-hooks/dist/hooks.custom-props.css">
    <!-- Your application's other stylesheets go below -->
    <link rel="stylesheet" href="...">
  </head>
  <body>
    <!-- Your application -->
  </body>
</html>
```

There are also other ways [`wes-styling-hooks`](https://www.npmjs.com/package/@salesforce-ux/wes-styling-hooks) can be embedded. Please checkout the [`wes-styling-hooks` Integration Guide](https://www.npmjs.com/package/@salesforce-ux/wes-styling-hooks) to learn more.


> #### Component CSS Import
```css
/* myComponent.css */
@import "@salesforce-ux/wes-button-toggle/dist/button-toggle.compiled.css";
```

> #### HTML Decoration
After that,the HTML of your LWC component template needs to be decorated to have all the named part attributes as per the [component's specification](./button-toggle.spec.md).
Below is a reference to the component's structure.
```html
<wes-button-toggle>
  <button part="button">
    Toggle
    <wes-icon symbol="add" slot="end"></wes-icon>
    <wes-icon symbol="check" slot="end"></wes-icon>
    <wes-icon symbol="close" slot="end"></wes-icon>
  </button>
</wes-button>
```

### For `Non LWC` Application


> #### Dependency Inclusion [Read the section above](#dependency-inclusion)


> #### Component Import
```js
/* myComponent.js */
import WESButtonToggle from '@salesforce-ux/wes-button-toggle/button-toggle';
```

> #### Component Registration
```js
/* myComponent.js */
customElements.define('wes-button-toggle', WESButtonToggle);
```

#### Example

Below is one approach to integrate your `wes-button-toggle` component.
##### Script
```js
/* myComponent.js */
import "@salesforce-ux/wes-styling-hooks/dist/hooks.custom-props.css";
import WESButtonToggle from "@salesforce-ux/wes-button-toggle/dist/button-toggle";
window.customElements.define('wes-button-toggle', WESButtonToggle);

```

##### HTML
```html
<wes-button-toggle>Toggle</wes-button-toggle>
```

## Interactive Demo
To see more examples with interactive demo, please visit `WES Subsytem`'s [Storybook Environment](https://wes-subsystem-storybook.herokuapp.com/?path=/story/wes-subsystem-components-button-toggle--base)

==> wes-button-toggle-0.1.2.tgz: package/README.md <==
# `@salesforce-ux/wes-button-toggle`
[![npm (custom registry)](https://img.shields.io/npm/v/@salesforce-ux/wes-button-toggle/latest?color=green&label=npm%20package)](https://www.npmjs.com/package/@salesforce-ux/wes-button-toggle)

## About

The Button Toggle provides feedback of its pressed and unpressed state.

## Getting Started

Let's start by installing wes-button-toggle as a dependency of your project with [npm](https://www.npmjs.com/package/@salesforce-ux/wes-button-toggle).

```
npm i @salesforce-ux/wes-button-toggle
```
## Distributable
After installation, all the distributables for the `wes-button-toggle` are found under `/node_modules/@salesforce-ux/wes-button-toggle/dist/` folder.

|File Name             |Description     |
|--------------------- |--------------- |
|`button-toggle.css`          | The CSS file specific to `wes-button-toggle` only. It doesnot include the styles for it's parent `sds-button-toggle`. `wes-button-toggle` extends from `sds-button-toggle`|
|`button-toggle.compiled.css` | The Compiled CSS file for `wes-button-toggle`. This file includes styles for both `wes-button-toggle` and its parent `sds-button-toggle`. This file is useful for **LWC** applications.([see below](#for-lightning-web-componentlwc-application) &rarr;)|
|`button-toggle.js`           | The bundled JS file for `wes-button-toggle` component. This file is useful for **Non LWC** applications.([see below](#for-non-lwc-application) &rarr;)|

## `wes-button-toggle` Integration

For the sake of understanding, we have categorized the development environment into LWC and Non LWC application. If you are using the Salesforce Experience Cloud platform, WES is supported through an Unlocked Package, see the [Confluence page for the WES Unlocked Package](https://confluence.internal.salesforce.com/display/CSGT4GG/Website+Experience+Subsystem+%28WES%29+Unlocked+Package).

This Guide covers the integration approach for these two types of application.

### For `Lightning Web Component(LWC)` Application

> #### Dependency Inclusion

[`wes-styling-hooks`](https://www.npmjs.com/package/@salesforce-ux/wes-styling-hooks) is a styling dependency for `wes-button-toggle`. Hence, this needs to be embedded into the root of the web app in order to make the `wes-button-toggle` render properly.

```html
<html>
  <head>
    <link rel="stylesheet" href="/node_modules/@salesforce-ux/wes-styling-hooks/dist/hooks.custom-props.css">
    <!-- Your application's other stylesheets go below -->
    <link rel="stylesheet" href="...">
  </head>
  <body>
    <!-- Your application -->
  </body>
</html>
```

There are also other ways [`wes-styling-hooks`](https://www.npmjs.com/package/@salesforce-ux/wes-styling-hooks) can be embedded. Please checkout the [`wes-styling-hooks` Integration Guide](https://www.npmjs.com/package/@salesforce-ux/wes-styling-hooks) to learn more.


> #### Component CSS Import
```css
/* myComponent.css */
@import "@salesforce-ux/wes-button-toggle/dist/button-toggle.compiled.css";
```

> #### HTML Decoration
After that,the HTML of your LWC component template needs to be decorated to have all the named part attributes as per the [component's specification](./button-toggle.spec.md).
Below is a reference to the component's structure.
```html
<wes-button-toggle>
  <button part="button">
    Toggle
    <wes-icon symbol="add" slot="end"></wes-icon>
    <wes-icon symbol="check" slot="end"></wes-icon>
    <wes-icon symbol="close" slot="end"></wes-icon>
  </button>
</wes-button>
```

### For `Non LWC` Application


> #### Dependency Inclusion [Read the section above](#dependency-inclusion)


> #### Component Import
```js
/* myComponent.js */
import WESButtonToggle from '@salesforce-ux/wes-button-toggle/button-toggle';
```

> #### Component Registration
```js
/* myComponent.js */
customElements.define('wes-button-toggle', WESButtonToggle);
```

#### Example

Below is one approach to integrate your `wes-button-toggle` component.
##### Script
```js
/* myComponent.js */
import "@salesforce-ux/wes-styling-hooks/dist/hooks.custom-props.css";
import WESButtonToggle from "@salesforce-ux/wes-button-toggle/dist/button-toggle";
window.customElements.define('wes-button-toggle', WESButtonToggle);

```

##### HTML
```html
<wes-button-toggle>Toggle</wes-button-toggle>
```

## Interactive Demo
To see more examples with interactive demo, please visit `WES Subsytem`'s [Storybook Environment](https://wes-subsystem-storybook.herokuapp.com/?path=/story/wes-subsystem-components-button-toggle--base)
